@@ -31,6 +31,7 @@ def test_statsmodel_to_df(func):
         raw = simulate_nirs_raw(sfreq=3., amplitude=amplitude,
                                 sig_dur=300., stim_dur=5.,
                                 isi_min=15., isi_max=45.)
+        raw._data += np.random.normal(0, np.sqrt(1e-12), raw._data.shape)
         design_matrix = make_first_level_design_matrix(raw, stim_dur=5.0)
         glm_est = run_GLM(raw, design_matrix)
         with pytest.warns(RuntimeWarning, match='Non standard source detect'):
@@ -42,7 +43,7 @@ def test_statsmodel_to_df(func):
                      groups=df_cha["ID"]).fit()
     df = statsmodels_to_results(roi_model)
     assert type(df) == pd.DataFrame
-    assert_allclose(df["Coef."]["Condition[A]"], amplitude, rtol=1e-12)
+    assert_allclose(df["Coef."]["Condition[A]"], amplitude, rtol=0.1)
     assert df["Significant"]["Condition[A]"]
     assert df.shape == (8, 8)
 
@@ -50,6 +51,6 @@ def test_statsmodel_to_df(func):
                         groups=df_cha["ID"]).fit()
     df = statsmodels_to_results(roi_model)
     assert type(df) == pd.DataFrame
-    assert_allclose(df["Coef."]["Condition[A]"], amplitude, rtol=1e-12)
+    assert_allclose(df["Coef."]["Condition[A]"], amplitude, rtol=0.1)
     assert df["Significant"]["Condition[A]"]
     assert df.shape == (8, 8)
